@@ -23,7 +23,6 @@ from tornado import escape
 from tornado.auth import OAuth2Mixin
 from tornado.httpclient import HTTPClientError, HTTPRequest
 
-import univention.debug as ud
 from univention.management.console.config import ucr
 from univention.management.console.error import BadRequest, NotFound, OpenIDProvideUnavailable, UMC_Error, Unauthorized
 from univention.management.console.log import CORE
@@ -123,7 +122,7 @@ class OIDCResource(OAuth2Mixin, Resource):
                 code_verifier=code_verifier,
             )
         except HTTPClientError as exc:
-            CORE.error('Could not get access token: %s' % (exc.response and exc.response.body or exc,))
+            CORE.error('Could not get access token: %s', exc.response and exc.response.body or exc)
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
         try:
@@ -133,9 +132,9 @@ class OIDCResource(OAuth2Mixin, Resource):
         except KeyError:
             raise OpenIDProvideUnavailable(self._("Authorization server response did not contain token."))
 
-        ud.debug(ud.MAIN, 99, 'Access token: %s' % (access_token,))
-        ud.debug(ud.MAIN, 99, 'ID token: %s' % (id_token,))
-        ud.debug(ud.MAIN, 99, 'Refresh token: %s' % (refresh_token,))
+        CORE.log(1, 'Access token: %s', access_token)
+        CORE.log(1, 'ID token: %s', id_token)
+        CORE.log(1, 'Refresh token: %s', refresh_token)
         claims = self.verify_id_token(id_token, nonce)
         oidc = OIDCUser(id_token, access_token, refresh_token, claims)
         await self.pam_oidc_authentication(oidc)
@@ -231,25 +230,25 @@ class OIDCResource(OAuth2Mixin, Resource):
                 leeway=ucr.get_int('umc/oidc/grace-time', 3),  # seconds
             )
         except jwt.ExpiredSignatureError:
-            CORE.warn("Signature expired")
+            CORE.warning("Signature expired")
             raise Unauthorized(self._("The Token signature is expired."))
         except jwt.InvalidSignatureError as exc:
-            CORE.error("Invalid signature: %s" % (exc,))
+            CORE.error("Invalid signature: %s", exc)
             raise Unauthorized(self._('The Token contains an invalid signature: %s') % (exc,))
         except jwt.InvalidIssuerError as exc:
-            CORE.warn("Invalid issuer: %s" % (exc,))
+            CORE.warning("Invalid issuer: %s", exc)
             raise Unauthorized(self._('The Token contains an invalid issuer: %s') % (exc,))
         except jwt.InvalidAudienceError as exc:
-            CORE.warn("Invalid signature: %s" % (exc,))
+            CORE.warning("Invalid signature: %s", exc)
             raise Unauthorized(self._('The Token contains an invalid audience: %s') % (exc,))
         except jwt.MissingRequiredClaimError as exc:
-            CORE.warn("Missing claim: %s" % (exc,))
+            CORE.warning("Missing claim: %s", exc)
             raise Unauthorized(self._('The Token is missing a required claim: %s') % (exc,))
         except jwt.ImmatureSignatureError as exc:
-            CORE.warn("Immature signature: %s" % (exc,))
+            CORE.warning("Immature signature: %s", exc)
             raise Unauthorized(self._('The Token contains an immature signature: %s') % (exc,))
 
-        CORE.debug('OIDC JWK-Payload: %r' % (claims,))
+        CORE.debug('OIDC JWK-Payload: %r', claims)
         return claims
 
     def _get_public_key(self, token):
@@ -271,11 +270,11 @@ class OIDCResource(OAuth2Mixin, Resource):
         try:
             user_info_res = await http_client.fetch(user_info_req)
         except HTTPClientError as exc:
-            CORE.warn("Fetching user info failed: %s %s" % (user_info_req.url, exc))
+            CORE.warning("Fetching user info failed: %s %s", user_info_req.url, exc)
             raise OpenIDProvideUnavailable(self._("Could not receive user information from OP."))
 
         user_info = json.loads(user_info_res.body.decode('utf-8'))
-        CORE.debug('OIDC User-Info: %r' % (user_info,))
+        CORE.debug('OIDC User-Info: %r', user_info)
         return user_info
 
     async def download_jwks(self):
@@ -285,11 +284,11 @@ class OIDCResource(OAuth2Mixin, Resource):
         try:
             response = await http_client.fetch(request, raise_error=False)
         except HTTPClientError as exc:
-            CORE.warn("Fetching certificate failed: %s %s" % (request.url, exc))
+            CORE.warning("Fetching certificate failed: %s %s", request.url, exc)
             raise OpenIDProvideUnavailable(self._("Could not receive certificate from OP."))
 
         if response.code != 200:
-            CORE.warn("Fetching certificate failed")
+            CORE.warning("Fetching certificate failed")
             raise OpenIDProvideUnavailable(self._("Could not receive certificate from OP."))
         return json.loads(response.body.decode('utf-8'))
 
@@ -328,13 +327,13 @@ class OIDCResource(OAuth2Mixin, Resource):
             )
         except HTTPClientError as exc:
             if not exc.response or exc.response.body is None:
-                CORE.error('OP response was empty or timed out. Could not get new access token: %s' % (exc,))
+                CORE.error('OP response was empty or timed out. Could not get new access token: %s', exc)
                 raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
             json_response = escape.json_decode(exc.response.body)
             if json_response.get('error') == 'invalid_grant':
                 if user.session_id in Session.sessions:
                     Session.sessions[user.session_id].logout(reload=False)
-            CORE.error('Could not get new access token: %s' % (json_response))
+            CORE.error('Could not get new access token: %s', json_response)
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
         try:
@@ -528,9 +527,9 @@ class OIDCBackchannelLogout(OIDCResource):
                     with get_session() as db_session:
                         session.delete(db_session, session.session_id, True)
                 except exc.DBAPIError as err:
-                    CORE.error('Deleting the session from the database during OIDC backchannel logout failed\n%s' % (err))
+                    CORE.error('Deleting the session from the database during OIDC backchannel logout failed: %s', err)
                 except exc.TimeoutError as err:
-                    CORE.error('Deleting the session from the database during OIDC backchannel logout timed out\n%s' % (err))
+                    CORE.error('Deleting the session from the database during OIDC backchannel logout timed out: %s', err)
                 except DBDisabledException:
                     pass
 
