@@ -135,17 +135,17 @@ class _ModuleConnection:
         try:
             response = function()
         except tornado.curl_httpclient.CurlError as exc:
-            CORE.warn('Reaching module failed: %s' % (exc,))
+            CORE.warning('Reaching module failed: %s', exc)
             raise CouldNotConnect(exc)
         except tornado.httpclient.HTTPError as exc:
             response = exc.response
             if response is None:  # (599, 'Timeout while connecting', None)
                 raise CouldNotConnect(exc)
         except ValueError as exc:  # HTTP GET request with body
-            CORE.warn('Reaching module failed: %s' % (exc,))
+            CORE.warning('Reaching module failed: %s', exc)
             raise BadRequest(str(exc))
         except asyncio.exceptions.CancelledError as exc:
-            CORE.warn('Aborted module process request: %s' % (exc,))
+            CORE.warning('Aborted module process request: %s', exc)
             raise CouldNotConnect(exc)
 
         return response
@@ -173,7 +173,7 @@ class ModuleProcess(_ModuleConnection):
         if no_daemonize_module_processes:
             args.extend(('-f', '-L', 'stdout'))
 
-        CORE.process('running: %s' % ' '.join(quote(x) for x in args))
+        CORE.process('running: %s', ' '.join(quote(x) for x in args))
         self.__process = tornado.process.Subprocess(args, stderr=subprocess.PIPE)
         # self.__process.initialize()  # TODO: do we need SIGCHILD handler?
         self.set_exit_callback(self._died)  # default
@@ -193,7 +193,7 @@ class ModuleProcess(_ModuleConnection):
             stderr_fd = self.__process.stderr
             stderr = stderr_fd.read().decode('utf-8', 'replace') if stderr_fd else ''
             if stderr:
-                CORE.error(stderr)
+                CORE.error('Process stderr: %s', stderr)
             raise CouldNotConnect('process died' + stderr)
         else:
             if connect_retries and not connect_retries % 50:
@@ -230,7 +230,7 @@ class ModuleProcess(_ModuleConnection):
 
     def stop(self):
         # type: () -> None
-        CORE.process('ModuleProcess: stopping %r' % (self.pid(),))
+        CORE.process('ModuleProcess: stopping %r', self.pid())
         if self.__process:
             tornado.ioloop.IOLoop.current().add_callback(self.stop_process)
 
@@ -247,7 +247,7 @@ class ModuleProcess(_ModuleConnection):
     def _died(self, returncode):
         # type: (int) -> None
         pid = self.pid()
-        CORE.process('ModuleProcess: child %d (%s) exited with %d%s' % (pid, self.name, returncode, self.str_returncode(returncode)))
+        CORE.process('ModuleProcess: child %d (%s) exited with %d%s', pid, self.name, returncode, self.str_returncode(returncode))
         if self._client and not self._client._closed:
             self._client.close()
         self.disconnect_inactivity_timer()
@@ -290,20 +290,20 @@ class ModuleProcess(_ModuleConnection):
         self._inactivity_timer = ioloop.call_later(MODULE_INACTIVITY_TIMER // 1000, self._mod_inactive)
 
     def _mod_inactive(self):
-        CORE.debug('The module %s is inactive for too long.' % (self.name,))
+        CORE.debug('The module %s is inactive for too long.', self.name)
         if self._active_requests:
-            CORE.debug('There are unfinished requests. Waiting for %s requests to finish.' % len(self._active_requests))
+            CORE.debug('There are unfinished requests. Waiting for %s requests to finish.', len(self._active_requests))
             ioloop = tornado.ioloop.IOLoop.current()
             self._inactivity_timer = ioloop.call_later(1, self._mod_inactive)
             return
 
         if self.__process:
-            CORE.info('Sending shutdown request to %s module' % (self.name,))
+            CORE.info('Sending shutdown request to %s module', self.name)
             try:
                 # or /exit HTTP request?
                 self.__process.proc.send_signal(signal.SIGALRM)
             except ProcessLookupError as exc:
-                CORE.warn('Could not shutdown module: %s' % (exc,))
+                CORE.warning('Could not shutdown module: %s', exc)
 
 
 class ModuleProxy(_ModuleConnection):
@@ -493,7 +493,7 @@ class Modules(Resource):
             for flavor in module.flavors
         ])
 
-        CORE.debug('Modules: %s' % (modules,))
+        CORE.debug('Modules: %s', modules)
         self.content_negotiation({'modules': modules}, wrap=False)
 
     def _flavor_definition(self, module, flavor, favorites):
@@ -546,7 +546,7 @@ class Modules(Resource):
         try:
             preferences = lo.get(user_dn, ['univentionUMCProperty']).get('univentionUMCProperty', [])
         except (ldap.LDAPError, udm_errors.base) as exc:
-            CORE.warn('Failed to retrieve user preferences: %s' % (exc,))
+            CORE.warning('Failed to retrieve user preferences: %s', exc)
             return {}
         preferences = (val.decode('utf-8', 'replace') for val in preferences)
         return dict(val.split('=', 1) if '=' in val else (val, '') for val in preferences)
@@ -578,7 +578,7 @@ class Categories(Resource):
                 'name': self.i18n._(category.name, category.domain).format(**_ucr_dict),
                 'priority': category.priority,
             })
-        CORE.debug('Categories: %s' % (categories,))
+        CORE.debug('Categories: %s', categories)
         self.content_negotiation({'categories': categories}, wrap=False)
 
     post = get
@@ -609,11 +609,17 @@ class Command(Resource):
     requires_authentication = False
 
     async def prepare(self, *args, **kwargs):
-        await super().prepare(*args, **kwargs)
+        self._request_id = Message.generate_id()
         self.future = None
         self.process = None
-        self._request_id = Message.generate_id()
         self._request_url = None
+        await super().prepare(*args, **kwargs)
+
+    def _request_context(self):
+        return {
+            **super()._request_context(),
+            'request_id': self._request_id[-10:],
+        }
 
     def forbidden_or_unauthenticated(self, message):
         # make sure that the UMC login dialog is shown if e.g. restarting the UMC-Server during active sessions
@@ -623,7 +629,7 @@ class Command(Resource):
 
     def on_connection_close(self):
         super().on_connection_close()
-        CORE.warn('Connection was aborted by the client!')
+        CORE.warning('Connection was aborted by the client!')
         self._remove_active_request()
         if self.future is not None:
             self.future.cancel()
@@ -634,7 +640,7 @@ class Command(Resource):
         fut = self.process.request("GET", "%s://%s/cancel" % (self._request_url.scheme, self._request_url.netloc), {'X-UMC-Request-ID': self._request_id})
 
         def cb(response):
-            CORE.process('Cancel request for %s completed with %d' % (self._request_id, response.result().code))
+            CORE.process('Cancel request for %s completed with %d', self._request_id, response.result().code)
 
         tornado.ioloop.IOLoop.current().add_future(fut, cb)
 
@@ -671,19 +677,19 @@ class Command(Resource):
         self._request_url = urlparse(self.request.full_url())
         module_name = acls.get_module_providing(moduleManager, command)
         if not module_name:
-            CORE.warn('No module provides %s' % (command))
+            CORE.warning('No module provides %s', command)
             raise self.forbidden_or_unauthenticated(self._("No module found for this request."))
 
-        CORE.info('Checking ACLs for %s (%s)' % (command, module_name))
+        CORE.info('Checking ACLs for %s (%s)', command, module_name)
         options = self.request.body_arguments
         flavor = self.request.headers.get('X-UMC-Flavor')
         if not acls.is_command_allowed(command, options, flavor):
-            CORE.warn('Command %s is not allowed' % (command))
+            CORE.warning('Command %s is not allowed', command)
             raise self.forbidden_or_unauthenticated(self._("Not allowed to perform this request."))
 
         methodname = acls.get_method_name(moduleManager, module_name, command)
         if not methodname:
-            CORE.warn('Command %s does not exists' % (command))
+            CORE.warning('Command %s does not exists', command)
             raise self.forbidden_or_unauthenticated(self._("Unknown request."))
 
         headers = self.get_request_header(session, methodname, umcp_command)
@@ -693,7 +699,7 @@ class Command(Resource):
         if not locale.territory:  # TODO: replace by using the actual provided value
             locale.territory = {'de': 'DE', 'fr': 'FR', 'en': 'US'}.get(self.locale.code)
         process = self.process = session.processes.get_process(module_name, str(locale), self.settings.get("no_daemonize_module_processes"))
-        CORE.info('Passing request to module %s' % (module_name,))
+        CORE.info('Passing request to module %s', module_name)
 
         try:
             await process.connect()
@@ -711,7 +717,7 @@ class Command(Resource):
             reason = 'UMC-Server module process connection failed'
             raise BadGateway('%s: %s: %s' % (self._('Connection to module process failed'), module_name, exc), reason=reason)
         else:
-            CORE.debug('Received response %s' % (response.code,))
+            CORE.debug('Received response %s', response.code)
             self.set_status(response.code, response.reason)
             self._headers = tornado.httputil.HTTPHeaders()
 
@@ -827,7 +833,7 @@ class Meta(Resource):
             with open(self.META_JSON_PATH) as fd:
                 meta_data = json.load(fd)
         except (OSError, ValueError) as exc:
-            CORE.error('meta.json is not available: %s' % (exc,))
+            CORE.error('meta.json is not available: %s', exc)
             meta_data = {}
 
         if not self.current_user.user.authenticated:
@@ -901,7 +907,7 @@ class Hosts(Resource):
             domaincontrollers = lo.search(filter="(objectClass=univentionDomainController)", attr=['cn', 'associatedDomain'])
         except (ldap.LDAPError, udm_errors.base) as exc:
             reset_ldap_connection_cache(lo)
-            CORE.warn('Could not search for domaincontrollers: %s' % (exc))
+            CORE.warning('Could not search for domaincontrollers: %s', exc)
             return []
 
         return sorted(
@@ -957,7 +963,7 @@ class SetLocale(Resource):
         try:
             lang = Locale(locale)
         except I18N_Error as exc:
-            CORE.warn('Invalid locale specified: %r -> %s' % (locale, exc))
+            CORE.warning('Invalid locale specified: %r -> %s', locale, exc)
             raise BadRequest(self._('Specified locale is not available'))
         self.current_user.user._locale = locale
         self.set_header('Content-Language', '%s-%s' % (lang.language, lang.territory) if lang.territory else lang.language)
@@ -984,7 +990,7 @@ class SetPassword(Resource):
             'new_password': new_password,
         }
 
-        CORE.info('Changing password of user %r' % (username,))
+        CORE.info('Changing password of user %r', username)
         try:
             await self.current_user.change_password(args)
         except PasswordChangeFailed as exc:
@@ -1014,7 +1020,7 @@ class UserPreferences(Resource):
         try:
             preferences = lo.get(user_dn, ['univentionUMCProperty']).get('univentionUMCProperty', [])
         except (ldap.LDAPError, udm_errors.base) as exc:
-            CORE.warn('Failed to retrieve user preferences: %s' % (exc,))
+            CORE.warning('Failed to retrieve user preferences: %s', exc)
             return {}
         preferences = (val.decode('utf-8', 'replace') for val in preferences)
         return dict(val.split('=', 1) if '=' in val else (val, '') for val in preferences)
@@ -1051,7 +1057,7 @@ class SetUserPreferences(UserPreferences):
         new_preferences = []
         for key, value in preferences.items():
             if not isinstance(key, str):
-                CORE.warn('user preferences keys needs to be strings: %r' % (key,))
+                CORE.warning('user preferences keys needs to be strings: %r', key)
                 continue
 
             # we can put strings directly into the dict
@@ -1094,12 +1100,12 @@ class SSELogoutNotifer(Resource):
 
         session_id = self.current_user.session_id
         self.for_session_id = session_id
-        CORE.debug("logout-sse requested for session_id %s" % (session_id, ))
+        CORE.debug("logout-sse requested for session_id %s", session_id)
 
         event = await logout_notifiers.get_or_set(session_id)
 
         await self.wait(event)
-        CORE.debug("logout-sse finished for session_id %s" % session_id)
+        CORE.debug("logout-sse finished for session_id %s", session_id)
 
         # the connection might have already been closed here, and we might not even have been logged out
         try:
